package net.wanji.web.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import net.wanji.common.annotation.aspect.AspectLog;
import net.wanji.common.enums.BaseEnum;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.feign.pojo.vo.*;
import net.wanji.web.service.FeignProxyService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

/**
 * @author duanruiming
 * @date 2023/01/04 16:10
 */
@Api(value = "SignalServiceController", description = "信号控制")
@RequestMapping("/controlCommand")
@RestController
@SuppressWarnings("all")
public class SignalCommandController {

    @Autowired
    private FeignProxyService feignProxyService;

    @AspectLog(description = "信号机方案下发-基础方案下发", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "信号机方案下发-基础方案下发", notes = "信号机方案下发-基础方案下发")
    @PostMapping("/schemeSend")
    public JsonViewObject schemeSend(@RequestBody @Validated SchemeSendVO schemeSendVO) {
        return feignProxyService.schemeSend(schemeSendVO);
    }

    @AspectLog(description = "计划下发-计划信息、时段信息", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "计划下发-计划信息、时段信息", notes = "计划下发-计划信息、时段信息 ")
    @PostMapping("/planSend")
    public JsonViewObject planSend(@RequestBody @Validated PlanSendVO planSendVO) {
        return feignProxyService.planSend(planSendVO);
    }

    @AspectLog(description = "时间表下发-时间表信息", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "时间表下发-时间表信息", notes = "时间表下发-时间表信息")
    @PostMapping("/scheduleSend")
    public JsonViewObject scheduleSend(@RequestBody @Validated ScheduleSendVO scheduleSendVO) {
        return feignProxyService.scheduleSend(scheduleSendVO);
    }

    @AspectLog(description = "相位配时下发-（下发相位参数）", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "相位配时下发-（下发相位参数）", notes = "相位配时下发-（下发相位参数）")
    @PostMapping("/phaseTimingSend")
    public JsonViewObject phaseTimingSend(@RequestBody @Validated PhaseTimingSendVO phaseTimingSendVO) {
        return feignProxyService.phaseTimingSend(phaseTimingSendVO);
    }

    @AspectLog(description = "灯态控制-路口全红/黄闪/关灯控制/恢复", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "灯态控制-路口全红/黄闪/关灯控制/恢复", notes = "灯态控制-路口全红/黄闪/关灯控制/恢复")
    @PostMapping("/lampStateControl")
    public JsonViewObject allRedControl(@RequestBody @Validated ControlCommandVO commandVO) {
        return feignProxyService.allRedControl(commandVO);
    }

    @AspectLog(description = "步进控制-步进控制/恢复", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "步进控制-步进控制/恢复", notes = "步进控制-步进控制/恢复")
    @PostMapping("/stepControl")
    public JsonViewObject stepControl(@RequestBody @Validated StepControlVO stepControlVO) {
        return feignProxyService.stepControl(stepControlVO);
    }

    @AspectLog(description = "恢复时间表-恢复路口时间表执行", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "恢复时间表-恢复路口时间表执行", notes = "恢复时间表-恢复路口时间表执行")
    @PostMapping("/recoverSchedule")
    public JsonViewObject recoverSchedule(@RequestParam String code) throws Exception {
        return feignProxyService.recoverSchedule(code);
    }

    @AspectLog(description = "锁定控制-相位锁定/解锁", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "锁定控制-相位锁定/解锁", notes = "锁定控制-相位锁定/解锁")
    @PostMapping(value = "/lockControl")
    public JsonViewObject lockControl(@RequestBody @Validated LockControlVO lockControlVO) {
        return feignProxyService.lockControl(lockControlVO);
    }

    @AspectLog(description = "相位差下发", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "相位差下发", notes = "相位差下发")
    @PostMapping("/phaseDiffSend")
    public JsonViewObject phaseDiffSend(HttpServletRequest httpServletRequest) {
        return feignProxyService.phaseDiffSend(httpServletRequest);
    }

}
