package net.wanji.web.controller;


import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import net.wanji.common.annotation.aspect.AspectLog;
import net.wanji.common.enums.BaseEnum;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.web.service.TBaseCrossInfoService;
import net.wanji.web.vo.BaseCrossInfoVO;
import net.wanji.web.vo.CrossInfoVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 路口基础表 前端控制器
 * </p>
 *
 * @author wj
 * @since 2022-11-28
 */
@Api(value = "路网管理-路口管理", description = "路网管理-路口管理", tags = "cross-info-controller")
@RestController
@RequestMapping("/crossInfo")
public class TBaseCrossInfoController {

    @Autowired
    private TBaseCrossInfoService crossInfoService;

    @AspectLog(description = "信号路口基础信息", operationType = BaseEnum.OperationTypeEnum.QUERY)
    @ApiOperation(value = "路网管理-路口管理-查询", notes = "路网管理-路口管理-查询")
    @PostMapping("/list")
    public JsonViewObject list(@RequestBody @Validated CrossInfoVO crossInfoVO) {
        return crossInfoService.selectAll(crossInfoVO);
    }

    @AspectLog(description = "路网管理-路口管理-修改", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "路网管理-路口管理-修改", notes = "路网管理-路口管理-修改")
    @PostMapping("/updateOne")
    public JsonViewObject updateOne(@RequestBody @Validated(BaseCrossInfoVO.Update.class) BaseCrossInfoVO crossInfoPO) {
        return crossInfoService.updateOne(crossInfoPO);
    }

    @AspectLog(description = "路网管理-路口管理-批量删除", operationType = BaseEnum.OperationTypeEnum.DELETE)
    @ApiOperation(value = "路网管理-路口管理-批量删除", notes = "路网管理-路口管理-批量删除")
    @PostMapping("/delete")
    public JsonViewObject delete(@RequestBody List<String> ids) {
        return crossInfoService.delete(ids);
    }

    @AspectLog(description = "路网管理-路口管理-增加", operationType = BaseEnum.OperationTypeEnum.INSERT)
    @ApiOperation(value = "路网管理-路口管理-增加", notes = "路网管理-路口管理-增加")
    @PostMapping("/addOne")
    public JsonViewObject addOne(@RequestBody @Validated(BaseCrossInfoVO.Save.class) BaseCrossInfoVO crossInfoPO) {
        return crossInfoService.addOne(crossInfoPO);
    }

    @AspectLog(description = "路网管理-路口管理-区域名称下拉框", operationType = BaseEnum.OperationTypeEnum.QUERY)
    @ApiOperation(value = "路网管理-路口管理-区域名称下拉框", notes = "路网管理-路口管理-区域名称下拉框")
    @GetMapping("/areaTree")
    public JsonViewObject areaTree() {
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        return jsonViewObject.success(crossInfoService.areaTree());
    }

}
